@@ -65,7 +65,7 @@ from OTAnalytics.application.config import (
     OTCONFIG_FILE_TYPE,
     OTFLOW_FILE_TYPE,
 )
-from OTAnalytics.application.export_formats.export_mode import INITIAL_MERGE, OVERWRITE
+from OTAnalytics.application.export_formats.export_mode import OVERWRITE
 from OTAnalytics.application.logger import logger
 from OTAnalytics.application.parser.flow_parser import FlowParser
 from OTAnalytics.application.playback import SkipTime
@@ -547,8 +547,8 @@ class DummyViewModel(
         self.treeview_videos.update_selected_items(current_paths)
         self._update_enabled_video_buttons()
 
-    def add_video(self) -> None:
-        track_files = self._ui_factory.askopenfilenames(
+    async def add_video(self) -> None:
+        track_files = await self._ui_factory.askopenfilenames(
             title="Load video files",
             filetypes=[("video file", SUPPORTED_VIDEO_FILE_TYPES)],
         )
@@ -592,9 +592,9 @@ class DummyViewModel(
         project = self._application._datastore.project
         self.frame_project.update(name=project.name, start_date=project.start_date)
 
-    def save_otconfig(self) -> None:
+    async def save_otconfig(self) -> None:
         suggested_save_path = self._application.suggest_save_path(OTCONFIG_FILE_TYPE)
-        configuration_file = self._ui_factory.ask_for_save_file_path(
+        configuration_file = await self._ui_factory.ask_for_save_file_path(
             title="Save configuration as",
             filetypes=[(f"{OTCONFIG_FILE_TYPE} file", f"*.{OTCONFIG_FILE_TYPE}")],
             defaultextension=f".{OTCONFIG_FILE_TYPE}",
@@ -640,9 +640,9 @@ class DummyViewModel(
             initial_position=self.treeview_sections.get_position(),
         )
 
-    def load_otconfig(self) -> None:
+    async def load_otconfig(self) -> None:
         otconfig_file = Path(
-            self._ui_factory.askopenfilename(
+            await self._ui_factory.askopenfilename(
                 title="Load configuration file",
                 filetypes=[
                     (f"{OTFLOW_FILE_TYPE} file", f"*.{OTFLOW_FILE_TYPE}"),
@@ -775,8 +775,8 @@ class DummyViewModel(
         ]
 
     @action
-    def load_tracks(self) -> None:
-        track_files = self._ui_factory.askopenfilenames(
+    async def load_tracks(self) -> None:
+        track_files = await self._ui_factory.askopenfilenames(
             title="Load track files", filetypes=[("tracks file", "*.ottrk")]
         )
         if not track_files:
@@ -785,16 +785,16 @@ class DummyViewModel(
         track_paths = [Path(file) for file in track_files]
         self._application.add_tracks_of_files(track_files=track_paths)
 
-    def load_configuration(self) -> None:  # sourcery skip: avoid-builtin-shadow
+    async def load_configuration(self) -> None:  # sourcery skip: avoid-builtin-shadow
         # INFO: Current behavior: Overwrites existing sections
         configuration_file = Path(
-            self._ui_factory.askopenfilename(
+            await self._ui_factory.askopenfilename(
                 title="Load sections file",
                 filetypes=[
                     (f"{OTFLOW_FILE_TYPE} file", f"*.{OTFLOW_FILE_TYPE}"),
                     (f"{OTCONFIG_FILE_TYPE} file", f"*.{OTCONFIG_FILE_TYPE}"),
                 ],
-                defaultextension=f".{OTFLOW_FILE_TYPE}",
+                defaultextension=f".{OTCONFIG_FILE_TYPE}",
             )
         )
         if not configuration_file.stem:
@@ -827,9 +827,9 @@ class DummyViewModel(
         self.set_selected_flow_ids([])
         self.refresh_items_on_canvas()
 
-    def save_configuration(self) -> None:
+    async def save_configuration(self) -> None:
         suggested_save_path = self._application.suggest_save_path(OTCONFIG_FILE_TYPE)
-        configuration_file = self._ui_factory.ask_for_save_file_path(
+        configuration_file = await self._ui_factory.ask_for_save_file_path(
             title="Save configuration as",
             filetypes=[
                 (f"{OTCONFIG_FILE_TYPE} file", f"*.{OTCONFIG_FILE_TYPE}"),
@@ -848,11 +848,11 @@ class DummyViewModel(
         else:
             raise ValueError("Configuration file to save has unknown file extension")
 
-    def quick_save_configuration(self) -> None:
+    async def quick_save_configuration(self) -> None:
         try:
             self._application.quick_save_configuration()
         except NoExistingFileToSave:
-            self.save_configuration()
+            await self.save_configuration()
 
     def _save_otflow(self, otflow_file: Path) -> None:
         logger().info(f"Sections file to save: {otflow_file}")
@@ -1292,6 +1292,10 @@ class DummyViewModel(
             initial_position=self.get_position(),
         )
         self._application.create_events()
+
+        # TODO find appropriate place to trigger update of plots
+        # self._application.update_count_plots()
+
         self.notify_flows(self.get_all_flow_ids())
         start_msg_popup.update_message(message="Creating events completed")
         sleep(1)
@@ -1304,13 +1308,13 @@ class DummyViewModel(
         self._application.save_events(Path(file))
         logger().info(f"Eventlist file saved to '{file}'")
 
-    def export_events(self) -> None:
+    async def export_events(self) -> None:
         export_format_extensions: dict[str, str] = {
             key: exporter.get_extension()
             for key, exporter in self._event_list_export_formats.items()
         }
         try:
-            event_list_exporter, file = self._configure_event_exporter(
+            event_list_exporter, file = await self._configure_event_exporter(
                 export_format_extensions
             )
             self._application.export_events(Path(file), event_list_exporter)
@@ -1320,10 +1324,10 @@ class DummyViewModel(
         except CancelExportFile:
             logger().info("User canceled configuration of export")
 
-    def _configure_event_exporter(
+    async def _configure_event_exporter(
         self, export_format_extensions: dict[str, str]
     ) -> tuple[EventListExporter, Path]:
-        export_config = self._ui_factory.configure_export_file(
+        export_config = await self._ui_factory.configure_export_file(
             title="Export events",
             export_format_extensions=export_format_extensions,
             initial_file_stem=CONTEXT_FILE_TYPE_EVENTS,
@@ -1499,7 +1503,7 @@ class DummyViewModel(
         self._application.disable_filter_track_by_class()
         self.frame_filter.disable_filter_by_class_button()
 
-    def export_counts(self) -> None:
+    async def export_counts(self) -> None:
         if len(self._application.get_all_flows()) == 0:
             self._ui_factory.info_box(
                 message=(
@@ -1521,7 +1525,7 @@ class DummyViewModel(
             self._application._tracks_metadata.filtered_detection_classifications
         )
         try:
-            export_specification = self._ui_factory.configure_export_counts(
+            export_specification = await self._ui_factory.configure_export_counts(
                 start=start,
                 end=end,
                 default_format=default_format,
@@ -1602,14 +1606,10 @@ class DummyViewModel(
     ) -> None:
         self._button_quick_save_config = button_quick_save_config
 
-    def export_road_user_assignments(self) -> None:
+    async def export_road_user_assignments(self) -> None:
         if len(self._application.get_all_flows()) == 0:
             self._ui_factory.info_box(
-                message=(
-                    "Counting needs at least one flow.\n"
-                    "There is no flow configured.\n"
-                    "Please create a flow."
-                ),
+                message=("There is no flow configured.\n" "Please create a flow."),
                 initial_position=self.get_position(),
             )
             return
@@ -1619,7 +1619,7 @@ class DummyViewModel(
         }
 
         try:
-            export_config = self._ui_factory.configure_export_file(
+            export_config = await self._ui_factory.configure_export_file(
                 title="Export road user assignments",
                 export_format_extensions=export_formats,
                 initial_file_stem="road_user_assignments",
@@ -1714,7 +1714,7 @@ class DummyViewModel(
     def get_tracks_assigned_to_each_flow(self) -> dict[FlowId, int]:
         return self._application.number_of_tracks_assigned_to_each_flow()
 
-    def export_track_statistics(self) -> None:
+    async def export_track_statistics(self) -> None:
         if self._application.get_track_repository_size() == 0:
             self._ui_factory.info_box(
                 message=(
@@ -1730,7 +1730,7 @@ class DummyViewModel(
         }
 
         try:
-            export_config = self._ui_factory.configure_export_file(
+            export_config = await self._ui_factory.configure_export_file(
                 title="Export track statistics",
                 export_format_extensions=export_formats,
                 initial_file_stem=CONTEXT_FILE_TYPE_TRACK_STATISTICS,
@@ -1741,7 +1741,7 @@ class DummyViewModel(
             export_format = export_config.export_format
 
             export_specification = TrackStatisticsExportSpecification(
-                save_path, export_format, INITIAL_MERGE
+                save_path, export_format, OVERWRITE
             )
             self._application.export_track_statistics(export_specification)
             logger().info(f"Exporting track statistics to {save_path}")
