@@ -5,6 +5,7 @@ from datetime import datetime
 from pathlib import Path
 from typing import Callable, Generic, Optional
 
+from OTAnalytics.application.analysis.traffic_counting import CountImage
 from OTAnalytics.application.config import DEFAULT_TRACK_OFFSET
 from OTAnalytics.application.datastore import Datastore
 from OTAnalytics.application.playback import SkipTime
@@ -112,6 +113,15 @@ class ObservableProperty(Generic[VALUE]):
         """
         self._subject.register(observer)
 
+    def unregister(self, observer: Callable[[VALUE], None]) -> None:
+        """
+        Stop listening to property changes.
+
+        Args:
+            observer (Observer[VALUE]): observer to be removed
+        """
+        self._subject.unregister(observer)
+
     def set(self, value: VALUE) -> None:
         """
         Change the current value of the property
@@ -152,6 +162,14 @@ class ObservableOptionalProperty(Generic[VALUE]):
         """
         self._subject.register(observer)
 
+    def unregister(self, observer: Callable[[Optional[VALUE]], None]) -> None:
+        """
+        Stop listening to property changes.
+        Args:
+            observer (Observer[VALUE]): observer to be removed
+        """
+        self._subject.unregister(observer)
+
     def set(self, value: Optional[VALUE]) -> None:
         """
         Change the current value of the property
@@ -206,6 +224,8 @@ class TrackViewState:
         ](default=[])
         self.skip_time = ObservableProperty[SkipTime](DEFAULT_SKIP_TIME)
 
+        self.count_plots = ObservableProperty[list[CountImage]](default=[])
+
     def reset(self) -> None:
         """Reset to default settings."""
         self.selected_videos.set([])
@@ -217,6 +237,8 @@ class TrackViewState:
         self.track_offset.set(DEFAULT_TRACK_OFFSET)
         self.skip_time.set(DEFAULT_SKIP_TIME)
 
+        self.count_plots.set([])
+
 
 class LiveImage:
     """
@@ -225,6 +247,7 @@ class LiveImage:
 
     def __init__(self) -> None:
         self.image = ObservableOptionalProperty[TrackImage]()
+        self.frame_number = ObservableOptionalProperty[int]()
 
 
 class TrackImageSizeUpdater:
