@@ -282,6 +282,14 @@ class PandasTrackDataset(TrackDataset, PandasDataFrameProvider):
     def empty(self) -> bool:
         return self._dataset.empty
 
+    @property
+    def track_geometry_factory(self) -> TRACK_GEOMETRY_FACTORY:
+        return self._track_geometry_factory
+
+    @property
+    def calculator(self) -> PandasTrackClassificationCalculator:
+        return self._calculator
+
     def __init__(
         self,
         track_geometry_factory: TRACK_GEOMETRY_FACTORY,
@@ -296,8 +304,8 @@ class PandasTrackDataset(TrackDataset, PandasDataFrameProvider):
         else:
             self._dataset = create_empty_dataframe()
 
-        self.calculator = calculator
-        self.track_geometry_factory = track_geometry_factory
+        self._calculator = calculator
+        self._track_geometry_factory = track_geometry_factory
         if geometry_datasets is None:
             self._geometry_datasets = dict[
                 RelativeOffsetCoordinate, TrackGeometryDataset
@@ -737,10 +745,15 @@ class FilteredPandasTrackDataset(
     FilteredTrackDataset, PandasTrackDataset, PandasDataFrameProvider
 ):
 
-    def __init__(
-        self,
-        other: PandasTrackDataset,
-    ) -> None:
+    @property
+    def track_geometry_factory(self) -> TRACK_GEOMETRY_FACTORY:
+        return self._other.track_geometry_factory
+
+    @property
+    def calculator(self) -> PandasTrackClassificationCalculator:
+        return self._other.calculator
+
+    def __init__(self, other: PandasTrackDataset) -> None:
         self._other = other
 
     def add_all(self, other: Iterable[Track]) -> PandasTrackDataset:
@@ -1008,13 +1021,11 @@ class FilterLastNDetectionsPandasTrackDataset(FilteredPandasTrackDataset):
 
 def get_latest_occurrences(dataframe: DataFrame, last_n: int) -> DataFrame:
     index_names = dataframe.index.names
-    dataframe.reset_index(inplace=True)
-    dataframe[RANK] = dataframe.groupby(track.TRACK_ID)[track.OCCURRENCE].rank(
+    result = dataframe.reset_index()
+    result.loc[:, RANK] = result.groupby(track.TRACK_ID)[track.OCCURRENCE].rank(
         method="first", ascending=False
     )
-    result = (
-        dataframe[dataframe[RANK] <= last_n].drop(RANK, axis=1).reset_index(drop=True)
-    )
+    result = result[result[RANK] <= last_n].drop(RANK, axis=1).reset_index(drop=True)
     return result.set_index(index_names)
 
 
