@@ -14,11 +14,13 @@ echo "Install OTAnalytics."
 echo "$DIR"
 cd "$DIR" || exit
 WORKING_DIR=$(pwd)
-VENV="$WORKING_DIR"/venv
+VENV="$WORKING_DIR"/.venv
 PYTHON="$VENV"/bin/python
 PIP="$VENV"/bin/pip
+UV="$VENV"/bin/uv
 
 python3.12 -m venv "$VENV"
 
 $PYTHON -m pip install --upgrade pip
-$PIP install -r requirements.txt --no-cache-dir
+$PIP install uv
+$UV pip install -r requirements.txt --python .venv
